@@ -1,6 +1,8 @@
 from .drive import *
 from .filesystem import *
+from .linux_volume import *
 from .logical_volume import *
 from .partition import *
 from .physical_volume import *
+from .simple import *
 from .volume_group import *
